import logging

# Public stuff
from cf_extension_core.interface import CustomResourceHelpers, generate_dynamodb_resource  # noqa: F401
from cf_extension_core.base_handler import BaseHandler  # noqa: F401


# Package Logger
# Set up logging to ``/dev/null`` like a library is supposed to.
# http://docs.python.org/3.3/howto/logging.html#configuring-logging-for-a-library
logging.getLogger(__name__).addHandler(logging.NullHandler())



from _typeshed import Incomplete
from cf_extension_core.constants import DynamoDBValues as DynamoDBValues
from mypy_boto3_dynamodb.service_resource import DynamoDBServiceResource
from typing import TYPE_CHECKING

logger: Incomplete

class DynamoTableCreator:
    _client: Incomplete
    def __init__(self, db_resource: DynamoDBServiceResource) -> None: ...
    def delete_table(self) -> None: ...
    def table_exists(self) -> bool: ...
    def create_standard_table(self) -> None: ...
    def _create_table(self, name: str, partition_key: str) -> None: ...
    def _wait_for_table_to_be_active(self) -> None: ...
    def _wait_for_table_to_be_deleted(self) -> None: ...
